Grappelli 2.3.x Release Notes — Django Grappelli v2.3.5 documentation

### Navigation

- index
- next |
- previous |
- Django Grappelli v2.3.5 documentation »

# Grappelli 2.3.x Release Notes

Grappelli 2.3.x is compatible with Django 1.3. We tried to simplify the codebase, cleaned up the javascripts and added this (sphinx-based) documentation.

## Overview

- Javascript cleanup: we changed some js-locations and tried to use a consistent and comprehensible naming-scheme. Grappelli javascripts have been reworked as jQuery-plugins/widgets. See Javascripts.
- Documentation: Added sphinx-based documentation.
- Simplified the Installation.

## What’s new in Grappelli 2.3.x

- Drag/drop for Inlines, see Inline Sortables.
- Grappelli Dashboard, see Dashboard.

## Deprecated in 2.3.x

- Actions for CSV-Export.
- Support for Admin-Tools.

A special thanks goes to David Jean-Louis, who’s responsible for Django Admin Tools. We also thank Klemens Mantzos and Maxime Haineault for their help with js-refactoring.

### Navigation

- index
- next |
- previous |
- Django Grappelli v2.3.5 documentation »